#include <fork.h>
#include <io.h>

sh simple_lock l1, l2;

void main( void ) {            /* !deadlock! */
  simple_lock_init( l1 );   simple_lock_init( l2 );
  if (__PROC_NR__ % 2) {
     simple_lockup( &l1 );
     prS("section 1, my processor ID is odd\n");
     simple_lockup( &l2 );
     prS("section 2, my processor ID is odd\n");
     simple_unlock( &l2 );         
     simple_unlock( &l1 );
  } else {  
     simple_lockup( &l2 );
     prS("section 2, my processor ID is even\n");
     simple_lockup( &l1 );
     prS("section 1, my processor ID is even\n");
     simple_unlock( &l1 );
     simple_unlock( &l2 );
  }
  barrier;
}
